summaryrefslogtreecommitdiffstats
path: root/src/exceptions
diff options
context:
space:
mode:
authorKore Nordmann <github@kore-nordmann.de>2006-08-07 07:48:06 +0000
committerKore Nordmann <github@kore-nordmann.de>2006-08-07 07:48:06 +0000
commitb31a0055fe42a14356400ebe6d7a8e5bebb26240 (patch)
treee7bb23aeeb54e09055bfd73539a08f7460aedaa3 /src/exceptions
parentf0c3843559d630bcd9458e8f5b15185445dd173b (diff)
downloadzetacomponents-graph-b31a0055fe42a14356400ebe6d7a8e5bebb26240.zip
zetacomponents-graph-b31a0055fe42a14356400ebe6d7a8e5bebb26240.tar.gz
- Renamed Dataset to DataSet
Diffstat (limited to 'src/exceptions')
-rw-r--r--src/exceptions/no_such_dataset.php4
-rw-r--r--src/exceptions/too_many_datasets.php4
-rw-r--r--src/exceptions/unknown_dataset_source.php4
3 files changed, 6 insertions, 6 deletions
diff --git a/src/exceptions/no_such_dataset.php b/src/exceptions/no_such_dataset.php
index 1346b3b..73093c9 100644
--- a/src/exceptions/no_such_dataset.php
+++ b/src/exceptions/no_such_dataset.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the ezcGraphNoSuchDatasetException class
*
* @package Graph
* @version //autogen//
@@ -14,7 +14,7 @@
* @package Graph
* @version //autogen//
*/
-class ezcGraphNoSuchDatasetException extends ezcGraphException
+class ezcGraphNoSuchDataSetException extends ezcGraphException
{
public function __construct( $name )
{
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the ezcGraphNoSuchDatasetException class
+ * File containing the ezcGraphNoSuchDataSetException class
*
* @package Graph
diff --git a/src/exceptions/too_many_datasets.php b/src/exceptions/too_many_datasets.php
index 89e41b6..3578212 100644
--- a/src/exceptions/too_many_datasets.php
+++ b/src/exceptions/too_many_datasets.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the ezcGraphTooManyDatasetsExceptions class
*
* @package Graph
* @version //autogen//
@@ -14,7 +14,7 @@
* @package Graph
* @version //autogen//
*/
-class ezcGraphTooManyDatasetsExceptions extends ezcGraphException
+class ezcGraphTooManyDataSetsExceptions extends ezcGraphException
{
public function __construct()
{
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the ezcGraphTooManyDatasetsExceptions class
+ * File containing the ezcGraphTooManyDataSetsExceptions class
*
* @package Graph
diff --git a/src/exceptions/unknown_dataset_source.php b/src/exceptions/unknown_dataset_source.php
index 7641f2b..63beb52 100644
--- a/src/exceptions/unknown_dataset_source.php
+++ b/src/exceptions/unknown_dataset_source.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the ezcGraphUnknownDatasetSourceException class
*
* @package Graph
* @version //autogen//
@@ -14,7 +14,7 @@
* @package Graph
* @version //autogen//
*/
-class ezcGraphUnknownDatasetSourceException extends ezcGraphException
+class ezcGraphUnknownDataSetSourceException extends ezcGraphException
{
public function __construct( $source )
{
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the ezcGraphUnknownDatasetSourceException class
+ * File containing the ezcGraphUnknownDataSetSourceException class
*
* @package Graph
OpenPOWER on IntegriCloud